def dftodict(dataframe):
    """This function takes the dataframe
    as a parameter and convert to dictionary """

    dummy_dict={key:"" for key in dataframe.columns.to_list()}
    dummy_dict_lst=[]
    for index,row in dataframe.iterrows():
        dummy_dict1={key:row[key] for key in dummy_dict.keys()}
        dummy_dict_lst.append(dummy_dict1.copy())
    return dummy_dict_lst
  


def WordAnalysis(dataframe,column):
    """This function will give the idea about the set of most used keywords
    included in dataframe column"""
    from wordcloud import WordCloud, STOPWORDS 
    import matplotlib.pyplot as plt
    from wordcloud import WordCloud, STOPWORDS, ImageColorGenerator
    import nltk
    from nltk.tokenize import word_tokenize
    from nltk.probability import FreqDist
    from nltk.corpus import stopwords
    from nltk.tokenize import sent_tokenize
    text = " ".join(review for review in dataframe[column])
    tokenized_word=word_tokenize(text)
    stop_words=set(stopwords.words("english"))
    filtered_sent=[]
    for w in tokenized_word:
        if w not in stop_words:
            if w not in [':',',','.',"'",'\\n','-','@','(',')','and/or','?',"'s"]:
                filtered_sent.append(w)
    fdist = FreqDist(filtered_sent)
    fdist.plot(30,cumulative=False)
    plt.show()
    
def WordCloud(dataframe,column):
    """ This function will give the word cloud for given dataframe column """
    from wordcloud import WordCloud
    import matplotlib.pyplot as plt
    import nltk
    from nltk.tokenize import word_tokenize
    from PIL import Image
    from nltk.corpus import stopwords
    from nltk.tokenize import sent_tokenize
    from wordcloud import WordCloud, STOPWORDS, ImageColorGenerator
    text = " ".join(review for review in dataframe[column])
    tokenized_word=word_tokenize(text)
    stop_words=set(stopwords.words("english"))
    filtered_sent=[]
    for w in tokenized_word:
        if w not in stop_words:
            if w not in [':',',','.',"'",'\\n','-','@','(',')','and/or','?',"'s"]:
                filtered_sent.append(w)
    wordcloud = WordCloud(margin=0,stopwords=stop_words,
                      max_words=200,background_color="white", collocations = False).generate(str(filtered_sent))
    plt.figure( figsize=(10,10), facecolor = None)
    plt.imshow(wordcloud,interpolation='bilinear')
    plt.axis("off")
    plt.margins(x=0, y=0)
    plt.show()



def create_engine(user,
        password,
        host,
        port,
        database):
    import sqlalchemy
    import psycopg2
    import psycopg2.extras

    try:
        connection = psycopg2.connect(user=user,
        password=password,
        host=host,
        port=port,
        database=database)
        print("Database Connection Established.")
    
    except Exception as ex:
        print("An exception occurred..check the provided credentials.",+ex)
    return connection
    
    
def insert_dict(connection,schemaname,tablename,dataframe):
    from vennam import DataFrameToDict 
    import time
    import psycopg2
    try:
        
        start_time=time.time()
        dict_data=DataFrameToDict.dftodict(dataframe)
        cursor=connection.cursor()
        insert_query=f' insert into {schemaname}.{tablename}  values %s'
        psycopg2.extras.execute_values(
                cursor, insert_query, [tuple(d.values()) for d in dict_data]
            )
        connection.commit()
        cnt=len(dict_data)
        end_time=time.time()
        Elapsed_time=end_time-start_time
        info=f' {cnt} Rows loaded into DataBase in : {Elapsed_time} sec'
        print(info)
    except Exception as ex:
        print(ex)
    finally :
        connection.close()


"""Setup script for vennam master"""

import os.path
from setuptools import setup

# The directory containing this file
HERE = os.path.abspath(os.path.dirname(__file__))

# The text of the README file
with open(os.path.join(HERE, "README.md")) as fid:
    README = fid.read()

# This call to setup() does all the work
setup(
    name="vennam",
    version="1.2.1",
    description="This package will helps to convert DataFrame to Dictionary and provide Exploratory Data Analysis.",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/deva567/vennam",
    author="Vennam",
    author_email="vennamdevendhar@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["vennam"],
    include_package_data=True,
    install_requires=[
        "pandas","wordcloud","nltk","matplotlib","Pillow","psycopg2","sqlalchemy"
    ],
)